ToolResultProvider class abstract

Provides tool execution results for binding resolution.

Constructors

ToolResultProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

executeAndGetResult(String toolName, Map<String, dynamic> args) Future
isAvailable() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited