VersionEntry class

A snapshot of a document version.

Constructors

VersionEntry({required String documentId, required int version, required FormDocument snapshot, TransitionResult? transition, required DateTime recordedAt})
const

Properties

documentId String
final
hashCode int
The hash code for this object.
no setterinherited
recordedAt DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snapshot → FormDocument
final
transition TransitionResult?
final
version int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited