BindingResult class
Result of binding resolution.
Constructors
-
BindingResult({required FormDocument boundDocument, List<
BoundField> boundFields = const [], List<UnfilledField> unfilledFields = const []}) -
const
Properties
- boundDocument → FormDocument
-
final
-
boundFields
→ List<
BoundField> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasUnfilled → bool
-
no setter
- resolutionRate → double
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalBindings → int
-
no setter
-
unfilledFields
→ List<
UnfilledField> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited