RenderContext class
Context passed to renderers during rendering.
Constructors
- RenderContext({required FormDocument document, required FormLayoutPolicy layoutPolicy, required FormTemplate template, RenderOptions options = const RenderOptions()})
-
const
Properties
- document → FormDocument
-
final
- effectiveWatermark → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- layoutPolicy → FormLayoutPolicy
-
final
- options → RenderOptions
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- template → FormTemplate
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited