TransitionRule class
Rule defining a valid state transition.
Constructors
- TransitionRule({required FormDocumentStatus from, required FormDocumentStatus to, bool requiresApproval = false, String? precondition(FormDocument document)?})
-
const
Properties
- from → FormDocumentStatus
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- precondition → String? Function(FormDocument document)?
-
Optional precondition validator. Returns an error message
if the precondition is not met, null if OK.
final
- requiresApproval → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- to → FormDocumentStatus
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited